function [z, varargout] = bhwolf(x, y, nAp, nCoeff, nstr),

% BHWOLF Sum of Bhatia-Wolf polynomials  (wrapper to the BSP object)
%
% BHWOLF(x, y, p, nstr). Where (x,y) is the cartesian point, nAp is the 
% aperture of the polynomial, nCoeff is the coefficient vector and str is 
% either the height ('z') or the required derivative ('dzdx', 'dzdy',
% 'dzdr', 'dzdt'.)  You should also be able to specify 'normal'. If strf is
% omitted then the default is height.
%
% [R, nArgList ] = BHWOLF('default').  Returns information for the RAYTRACE 
%  toolbox, namely a default zernike surface, along with the argument list.
% 
% f = BHWOLF('inline').  Not implemented here.
%
% Examples,
%   
%   nArgs = bhwolf('default'); 
%   z = bhwolf(1, 1.5, nArgs{:})
%
% see papers by Iskander et al. for more information.



if  ((nargin == 1)&(ischar(x))),
    switch(x),
        case { 'default' }
            nOrder = 10; nAp = 3; R = 7; 
            nCoeff = bhwConicCoeffs(1/R, 0, nAp, nOrder); 
            z = { nAp,  nCoeff }; 
            varargout = { { 'AP', 'COEFF' } };
        case { 'inline' },
            z = [];
        otherwise,
            error('(BHWOLF) Unknown invocation parameter.');
    end
    return
end

% try and determine 
[n, m] = bhwSgl2Dbl(size(nCoeff,1));
p = bhw(n); 
p = set(p, 'aperture', nAp);
p = set(p, 'coeff', nCoeff);
p = set(p, 'coord', 'cartesian');

if (nargin == 3),
    z = get(p, x, y);  
    return
end

if (nargin == 4),
    z = get(p, x, y);  
    return
end

switch(nstr)
  case { 'z' }
    z = get(p, x, y);  
  case { 'dzdx', 'dzdy', 'dzdr', 'dzdt' }
    z = getdv(p, x, y, nstr);
  case { 'normal' }
    z(:,1) = getdv(p, x, y, 'dzdx');
    z(:,2) = getdv(p, x, y, 'dzdy'); 
    z(:,3) = -1;   
  otherwise,  
    error('(BHWOLF) Unknown inovcation.');
end

return
