function z = bspline(x, y, p, nstr),

% BSPLINE Sum of Bhatia-Wolf polynomials (wrapper to the BSP object)
%
% BSPLINE(x, y, p, nstr). Where (x,y) is the cartesian point, p is the 
% BSP object and nstr is the height ('z') or the required derivative 
% {'dzdx','dzdy','dzdr','dzdt'}.  If strf is omitted then height is
% assumed.
%
% [R, nArgList ] = BSPLINE('default').  Returns information for the RAYTRACE 
%  toolbox, namely a default bspline surface, along with the argument list.
% 
% f = BSPLINE('inline').  Not implemented here.
%
%
% NOTE : 
%  * some features not implemented. 
%  * this may or may not work ... not properly tested. 

if  ((nargin == 1)&(ischar(x))),
    switch(x),
        case { 'default' }
            fprintf('(BSPLINE) ''DEFAULT'' NOT IMPLEMENTED.\n');    
            z = [];
        case { 'inline' },            
            z = [];
        otherwise,
            error('(BSPLINE) Unknown invocation parameter.');
    end
    return
end


switch(nstr)
  case { 'z' }
    z = get(p, x, y);  
  case { 'dzdx', 'dzdy', 'dzdr', 'dzdt' }
    z = getdv(p, x, y, nstr);
  case { 'normal' }
    z(:,1) = bsp(x, y, p, 'dzdx');
    z(:,2) = bsp(x, y, p, 'dzdy');
    z(:,3) = -1;   
  otherwise,  
    error('(BSPLINE) Unknown inovcation.');
end
return