function y = bhwRadialTermDvStr(n, m),


% BHWRADIALTERMDVSTR Bhatia-Wolf 1st radial derivative component of the 
% term string for polynomial-ordering number p
%
%   y = bhwRadialTermDvStr(n, m),
%
% where 
%       y = string
%       n = radial order
%       m = azimuthal frequency
% 
%
% see BHWTERM for details of the Bhatia-Wolf polynomials.
%
%
% implements Bhatia=Wolf polynomials as described in : 
%
% Modeling of Corneal Surfaces with Radial Polynomials. Iskander, DR;
% Morelande, MR; Collins MJ; Davis, B. IEEE Trams. Biomed. Eng. 49(4) April
% 2002. 


% (n=0, m=0)
if ((n==0))
    y = '0';  % N_mn = 0
    return
end


if      (m < n),
    
        y0 = bhwRadialCoeff(n, m);
        
        if ((n-1) > 1) 
            y = sprintf('%.0f*r.^%d',[n*y0(1) n-1]);
        elseif ((n-1) == 1),
            y = sprintf('%.0f*r',n*y0(1));
        else 
            % (n=1, m=0) 
            y = sprintf('%.0f',y0(1));
            return
            
        end 
        
                        
        
        % normal construction 
        for s = 1:(n-m)

            n0 = y0(s+1)*(n-s);
            
            % next polynomial term
            if  ( (n-s) == 0),
                
                if (n0 ~= 0 ),
                    % constant term    
                    y = strcat(y, sprintf('%+.0f',n0));
                end
                    
                    
            elseif  ((n-s-1) == 0),
                
                % leave the power ^1 off  
                y = strcat(y, sprintf('%+.0f',n0));        
                
            elseif  ((n-s-1) == 1),
         
                % leave the power ^1 off  
                y = strcat(y, sprintf('%+.0f*r',n0));        
            else
                % non-constant term
                y = strcat(y, sprintf('%+.0f*r.^%d',[n0 (n-s-1)]'));
            end
                        
        end 
        
elseif  (m == n)
    
        % this is a stand-alone term
        if  (n == 2),
            y = sprintf('%.0f*r',n);                        
        elseif (n > 2),
            y = sprintf('%.0f*r.^%d',[n n-1]');            
        else
            y = '1';
        end 
else
        error('m > n not allowed.');
end


return

