function y = bhwRepMtxDv(r, phi, N, str),

% BHWREPMTXDV Bhatia-Wolf representation matrix 
%
% Bhatia-Wolf matrix with columns (p = 1 ... N) over the
% polynomial-ordering parameter, and a row for each (r,phi) pair.  
%
%   y = bhwRepMtxDv(r, phi, p, str),
%
% where 
%       y   = Bhatia-Wolf matrix 
%       r   = radial distance (<= 1)
%       phi = angle in radians 
%       N   = maximum polynomial order (1<= p <= N)
%       str = 'rho' (radial derivatiove),'phi' (angular derivative)
%
% see BHWTERM for explanation of the Bhatia-Wolf polynomials        
%
% implements Bhatia=Wolf polynomials as described in : 
%
% Modeling of Corneal Surfaces with Radial Polynomials. Iskander, DR;
% Morelande, MR; Collins MJ; Davis, B. IEEE Trams. Biomed. Eng. 49(4) April
% 2002. 

r   = r(:);
phi = phi(:);

for p = 1:N,
    y(:,p) = bhwTermDv(r, phi, p, str);
end 

return 
