function y = bsp1ddv(i, p, kt, t)

% BSP1DDV Compute the 1-D B-Spline basis function at the particular point 
% (t). 
% 
% BSP1DDV(i, p, kt, t). Here the control point is i (i = 0, ..., N). The 
% degree p is related to the polynomial order by (p = k-1) e.g. p=3 is cubic. 
% The knot vector is given by kt, and the location of interest is t. 
% 
% The derivative basis function is such that, 
% 
%             N
%           -----
%   Z'(X) = >  C(I)*B'(I; P1)(X) 
%           -----
%           I = 0
% 
% NOTES : 
% 
%   30/10/06 seemed to be a error here !
%   30/10/06 derivative of heavisde assumed to be zero (not right).

% The order of the basis functions (2 <= k <= n+1). 

t  = t(:);
i0 = i + 1;
m  = length(kt) - 1;  % (m+1) knots

% funny input
if  (i > m-p-1)|(i<0),
    error('inconsistent control point/knot vector relationship.');
end

% all degree 0 (order 1 curves) are zero everywhere (except 
if  p == 0,
    y = 0*t; % ignores the fact that theres a nan in here 
    return
end

% see notes (where are these!) for derivation of this equation
alpha = bsp1d(i, p-1, kt, t) + (t - kt(i+1)).*bsp1ddv(i, p-1, kt, t);
beta  = (kt(i+p+1+1)-t).*bsp1ddv(i+1, p-1, kt, t)-bsp1d(i+1, p-1, kt, t);
delta = kt(i+p+1)-kt(i+1);
gamma = kt(i+p+1+1)-kt(i+1+1);

if    delta == 0,
      a = 0;
else
      a = alpha./delta;
end

if    gamma == 0,
      b = 0;
else
      b = beta./gamma;
end

y     = a + b;

return